<div class="table table-fixed w-full">
    <div class="readonly bg-base-50 border border-base-200 font-medium max-w-2xl px-3 py-2 rounded-default shadow-xs dark:bg-white/[.02] dark:border-base-700 {% if summary|length > 1 %} text-ellipsis overflow-hidden whitespace-nowrap w-full{% endif %}" {% include 'django/forms/widgets/attrs.html' %}>
        {% if summary|length > 1 %}
            {% for entry in summary %}
                <strong class="font-semibold text-font-important-light dark:text-font-important-dark">{{ entry.label }}</strong>{% if entry.value %}: {{ entry.value }}{% endif %}
            {% endfor %}
        {% else %}
            {% for entry in summary %}
                {{ entry.label }}
            {% endfor %}
        {% endif %}
    </div>
</div>
